@@ -3,7 +3,7 @@
 # Antimicrobial Resistance (AMR) Analysis                              #
 #                                                                      #
 # SOURCE                                                               #
-# https://gitlab.com/msberends/AMR                                     #
+# https://github.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
 # (c) 2018-2020 Berends MS, Luz CF et al.                              #
@@ -16,7 +16,7 @@
 # We created this package for both routine data analysis and academic  #
 # research and it was publicly released in the hope that it will be    #
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
-# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
+# Visit our website for more info: https://msberends.github.io/AMR.    #
 # ==================================================================== #
 
 #' Check availability of columns
@@ -46,6 +46,7 @@
 #'   availability()
 #' }
 availability <- function(tbl, width = NULL) {
+  stop_ifnot(is.data.frame(tbl), "`tbl` must be a data.frame")
   x <- base::sapply(tbl, function(x) {
     1 - base::sum(base::is.na(x)) / base::length(x) 
   })
@@ -54,7 +55,7 @@ availability <- function(tbl, width = NULL) {
   R_print <- character(length(R))
   R_print[!is.na(R)] <- percentage(R[!is.na(R)])
   R_print[is.na(R)] <- ""
-
+  
   if (is.null(width)) {
     width <- options()$width -
       (max(nchar(colnames(tbl))) +
@@ -68,19 +69,19 @@ availability <- function(tbl, width = NULL) {
          5)
     width <- width / 2
   }
-
+  
   if (length(R[is.na(R)]) == ncol(tbl)) {
     width <- width * 2 + 10
   }
-
+  
   x_chars_R <- strrep("#", round(width * R, digits = 2))
   x_chars_SI <- strrep("-", width - nchar(x_chars_R))
   vis_resistance <- paste0("|", x_chars_R, x_chars_SI, "|")
   vis_resistance[is.na(R)] <- ""
-
+  
   x_chars <- strrep("#", round(x, digits = 2) / (1 / width))
   x_chars_empty <- strrep("-", width - nchar(x_chars))
-
+  
   df <- data.frame(count = n,
                    available = percentage(x),
                    visual_availabilty = paste0("|", x_chars, x_chars_empty, "|"),
