@@ -3,7 +3,7 @@
 # Antimicrobial Resistance (AMR) Analysis                              #
 #                                                                      #
 # SOURCE                                                               #
-# https://gitlab.com/msberends/AMR                                     #
+# https://github.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
 # (c) 2018-2020 Berends MS, Luz CF et al.                              #
@@ -16,26 +16,28 @@
 # We created this package for both routine data analysis and academic  #
 # research and it was publicly released in the hope that it will be    #
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
-# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
+# Visit our website for more info: https://msberends.github.io/AMR.    #
 # ==================================================================== #
 
 #' Filter isolates on result in antimicrobial class
 #'
-#' Filter isolates on results in specific antimicrobial classes. This makes it easy to filter on isolates that were tested for e.g. any aminoglycoside.
+#' Filter isolates on results in specific antimicrobial classes. This makes it easy to filter on isolates that were tested for e.g. any aminoglycoside, or to filter on carbapenem-resistant isolates without the need to specify the drugs.
 #' @inheritSection lifecycle Stable lifecycle
 #' @param x a data set
-#' @param ab_class an antimicrobial class, like `"carbapenems"`, as can be found in [`antibiotics$group`][antibiotics]
+#' @param ab_class an antimicrobial class, like `"carbapenems"`. The columns `group`, `atc_group1` and `atc_group2` of the [antibiotics] data set will be searched (case-insensitive) for this value.
 #' @param result an antibiotic result: S, I or R (or a combination of more of them)
 #' @param scope the scope to check which variables to check, can be `"any"` (default) or `"all"`
-#' @param ... parameters passed on to `filter_at` from the `dplyr` package
-#' @details The `group` column in [antibiotics] data set will be searched for `ab_class` (case-insensitive). If no results are found, the `atc_group1` and `atc_group2` columns will be searched. Next, `x` will be checked for column names with a value in any abbreviations, codes or official names found in the [antibiotics] data set.
+#' @param ... previously used when this package still depended on the `dplyr` package, now ignored
+#' @details All columns of `x` will be searched for known antibiotic names, abbreviations, brand names and codes (ATC, EARS-Net, WHO, etc.). This means that a filter function like e.g. [filter_aminoglycosides()] will include column names like 'gen', 'genta', 'J01GB03', 'tobra', 'Tobracin', etc.
 #' @rdname filter_ab_class
+#' @seealso [antibiotic_class_selectors()] for the `select()` equivalent.
 #' @export
 #' @examples
 #' \dontrun{
 #' library(dplyr)
 #'
 #' # filter on isolates that have any result for any aminoglycoside
+#' example_isolates %>% filter_ab_class("aminoglycoside")
 #' example_isolates %>% filter_aminoglycosides()
 #'
 #' # this is essentially the same as (but without determination of column names):
@@ -45,7 +47,7 @@
 #'
 #'
 #' # filter on isolates that show resistance to ANY aminoglycoside
-#' example_isolates %>% filter_aminoglycosides("R")
+#' example_isolates %>% filter_aminoglycosides("R", "any")
 #'
 #' # filter on isolates that show resistance to ALL aminoglycosides
 #' example_isolates %>% filter_aminoglycosides("R", "all")
@@ -61,6 +63,10 @@
 #' example_isolates %>%
 #'   filter_aminoglycosides("R", "all") %>%
 #'   filter_fluoroquinolones("R", "all")
+#' 
+#' # with dplyr 1.0.0 and higher (that adds 'across()'), this is equal:
+#' example_isolates %>% filter_carbapenems("R", "all")
+#' example_isolates %>% filter(across(carbapenems(), ~. == "R"))
 #' }
 filter_ab_class <- function(x,
                             ab_class,
@@ -69,60 +75,86 @@ filter_ab_class <- function(x,
                             ...) {
   
   check_dataset_integrity()
+  stop_ifnot(is.data.frame(x), "`x` must be a data frame")
+  
+  # save to return later
+  x_class <- class(x)
+  x.bak <- x
+  x <- as.data.frame(x, stringsAsFactors = FALSE)
   
   scope <- scope[1L]
   if (is.null(result)) {
     result <- c("S", "I", "R")
   }
-  # make result = "SI" work too:
+  # make result = "SI" works too:
   result <- unlist(strsplit(result, ""))
   
-  if (!all(result %in% c("S", "I", "R"))) {
-    stop("`result` must be one or more of: S, I, R", call. = FALSE)
-  }
-  if (!all(scope %in% c("any", "all"))) {
-    stop("`scope` must be one of: any, all", call. = FALSE)
-  }
+  stop_ifnot(all(result %in% c("S", "I", "R")), "`result` must be one or more of: 'S', 'I', 'R'")
+  stop_ifnot(all(scope %in% c("any", "all")), "`scope` must be one of: 'any', 'all'")
   
-  # get only columns with class ab, mic or disk - those are AMR results
-  vars_df <- colnames(x)[sapply(x, function(y) is.rsi(y) | is.mic(y) | is.disk(y))]
-  vars_df_ab <- suppressWarnings(as.ab(vars_df))
-  # get the columns with a group names in the chosen ab class
-  vars_df <- vars_df[which(ab_group(vars_df_ab) %like% ab_class | 
-                             ab_atc_group1(vars_df_ab) %like% ab_class |
-                             ab_atc_group2(vars_df_ab) %like% ab_class)]
+  # get all columns in data with names that resemble antibiotics
+  ab_in_data <- suppressMessages(get_column_abx(x))
+  if (length(ab_in_data) == 0) {
+    message(font_blue("NOTE: no columns with class <rsi> found (see ?as.rsi), data left unchanged."))
+    return(x.bak)
+  }
+  # get reference data
+  ab_class.bak <- ab_class
+  ab_class <- gsub("[^a-zA-Z0-9]+", ".*", ab_class)
+  ab_class <- gsub("(ph|f)", "(ph|f)", ab_class)
+  ab_class <- gsub("(t|th)", "(t|th)", ab_class)
+  ab_reference <- subset(antibiotics,
+                         group %like% ab_class | 
+                           atc_group1 %like% ab_class | 
+                           atc_group2 %like% ab_class)
   ab_group <- find_ab_group(ab_class)
-  
-  if (length(vars_df) > 0) {
-    if (length(result) == 1) {
-      operator <- " is "
-    } else {
-      operator <- " is one of "
-    }
-    if (scope == "any") {
-      scope_txt <- " or "
-      scope_fn <- any
-    } else {
-      scope_txt <- " and "
-      scope_fn <- all
-      if (length(vars_df) > 1) {
-        operator <- gsub("is", "are", operator)
-      }
-    }
-    if (length(vars_df) > 1) {
-      scope <- paste(scope, "of columns ")
-    } else {
-      scope <- "column "
-    }
-    message(font_blue(paste0("Filtering on ", ab_group, ": ", scope,
-                             paste0(font_bold(paste0("`", vars_df, "`"), collapse = NULL), collapse = scope_txt), operator, toString(result))))
-    x[as.logical(by(x, seq_len(nrow(x)), function(row) scope_fn(unlist(row[, vars_df]) %in% result, na.rm = TRUE))), , drop = FALSE]
-  } else {
-    message(font_blue(paste0("NOTE: no antimicrobial agents of class ", ab_group, 
-                             " (such as ", find_ab_names(ab_group), 
-                             ") found, data left unchanged.")))
-    x
+  if (ab_group == "") {
+    message(font_blue(paste0("NOTE: unknown antimicrobial class '", ab_class.bak, "', data left unchanged.")))
+    return(x.bak)
   }
+  # get the columns with a group names in the chosen ab class
+  agents <- ab_in_data[names(ab_in_data) %in% ab_reference$ab]
+  if (length(agents) == 0) {
+    message(font_blue(paste0("NOTE: no antimicrobial agents of class ", ab_group, 
+                             " found (such as ", find_ab_names(ab_class, 2), 
+                             "), data left unchanged.")))
+    return(x.bak)
+  }
+  
+  if (length(result) == 1) {
+    operator <- " is "
+  } else {
+    operator <- " is one of "
+  }
+  if (scope == "any") {
+    scope_txt <- " or "
+    scope_fn <- any
+  } else {
+    scope_txt <- " and "
+    scope_fn <- all
+    if (length(agents) > 1) {
+      operator <- gsub("is", "are", operator)
+    }
+  }
+  if (length(agents) > 1) {
+    scope <- paste(scope, "of columns ")
+  } else {
+    scope <- "column "
+  }
+  
+  # sort columns on official name
+  agents <- agents[order(ab_name(names(agents), language = NULL))]
+  
+  message(font_blue(paste0("Filtering on ", ab_group, ": ", scope,
+                           paste(paste0("`", font_bold(agents, collapse = NULL),
+                                        "` (", ab_name(names(agents), tolower = TRUE, language = NULL), ")"),
+                                 collapse = scope_txt),
+                           operator, toString(result))))
+  x_transposed <- as.list(as.data.frame(t(x[, agents, drop = FALSE])))
+  filtered <- sapply(x_transposed, function(y) scope_fn(y %in% result, na.rm = TRUE))
+  x <- x[which(filtered), , drop = FALSE]
+  class(x) <- x_class
+  x
 }
 
 #' @rdname filter_ab_class
@@ -268,6 +300,19 @@ filter_macrolides <- function(x,
                   ...)
 }
 
+#' @rdname filter_ab_class
+#' @export
+filter_penicillins <- function(x,
+                               result = NULL,
+                               scope = "any",
+                               ...) {
+  filter_ab_class(x = x,
+                  ab_class = "penicillin",
+                  result = result,
+                  scope = scope,
+                  ...)
+}
+
 #' @rdname filter_ab_class
 #' @export
 filter_tetracyclines <- function(x,
@@ -282,6 +327,7 @@ filter_tetracyclines <- function(x,
 }
 
 find_ab_group <- function(ab_class) {
+  ab_class <- gsub("[^a-zA-Z0-9]", ".*", ab_class)
   ifelse(ab_class %in% c("aminoglycoside",
                          "carbapenem",
                          "cephalosporin",
@@ -297,13 +343,15 @@ find_ab_group <- function(ab_class) {
            pull(group) %>%
            unique() %>%
            tolower() %>%
+           sort() %>% 
            paste(collapse = "/")
   )
 }
 
-find_ab_names <- function(ab_group) {
-  drugs <- antibiotics[which(antibiotics$group %like% ab_group), "name"]
-  paste0(ab_name(sample(drugs, size = min(4, length(drugs)), replace = FALSE),
-                 tolower = TRUE, language = NULL), 
+find_ab_names <- function(ab_group, n = 3) {
+  ab_group <- gsub("[^a-zA-Z0-9]", ".*", ab_group)
+  drugs <- antibiotics[which(antibiotics$group %like% ab_group & !antibiotics$ab %like% "[0-9]$"), ]$name
+  paste0(sort(ab_name(sample(drugs, size = min(n, length(drugs)), replace = FALSE),
+                      tolower = TRUE, language = NULL)), 
          collapse = ", ")
 }
