@@ -3,7 +3,7 @@
 # Antimicrobial Resistance (AMR) Analysis                              #
 #                                                                      #
 # SOURCE                                                               #
-# https://gitlab.com/msberends/AMR                                     #
+# https://github.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
 # (c) 2018-2020 Berends MS, Luz CF et al.                              #
@@ -16,102 +16,50 @@
 # We created this package for both routine data analysis and academic  #
 # research and it was publicly released in the hope that it will be    #
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
-# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
+# Visit our website for more info: https://msberends.github.io/AMR.    #
 # ==================================================================== #
 
-globalVariables(c(".",
-                  "..property",
-                  "ab",
+globalVariables(c("ab",
                   "ab_txt",
-                  "abbreviations",
                   "angle",
-                  "antibiotic",
                   "antibiotics",
                   "atc_group1",
                   "atc_group2",
-                  "CNS_CPS",
                   "code",
-                  "col_id",
-                  "count",
-                  "count.x",
-                  "date_lab",
-                  "diff.percent",
-                  "First name",
-                  "first_isolate_row_index",
+                  "data",
                   "fullname",
                   "fullname_lower",
                   "g_species",
                   "genus",
                   "gr",
-                  "gramstain",
                   "group",
                   "hjust",
-                  "index",
                   "input",
-                  "interpretation",
                   "isolates",
-                  "item",
-                  "key_ab",
-                  "key_ab_lag",
-                  "key_ab_other",
-                  "kingdom",
-                  "kingdom_index",
                   "lang",
-                  "Last name",
                   "lookup",
-                  "mdr",
-                  "MDRO",
-                  "median",
                   "microorganisms",
                   "microorganisms.codes",
                   "microorganisms.old",
-                  "missing_names",
                   "mo",
-                  "mo_new",
-                  "mo_old",
-                  "mono_count",
-                  "more_than_episode_ago",
                   "name",
                   "new",
-                  "newvar_date",
-                  "newvar_genus_species",
-                  "newvar_mo",
-                  "newvar_patient_id",
-                  "newvar_row_index",
-                  "newvar_row_index_sorted",
                   "observations",
-                  "observed",
                   "old",
                   "old_name",
-                  "other_pat_or_mo",
-                  "package_version",
-                  "patient_id",
                   "pattern",
-                  "plural",
-                  "prevalence",
                   "R",
-                  "real_first_isolate",
-                  "ref",
                   "rsi_translation",
                   "rule_group",
                   "rule_name",
-                  "S",
                   "se_max",
                   "se_min",
-                  "second",
-                  "Sex",
                   "species",
                   "species_id",
-                  "subspecies",
-                  "synonyms",
                   "total",
                   "txt",
-                  "uncertainty_level",
                   "value",
                   "varname",
-                  "x",
-                  "xdr",
                   "xvar",
-                  "y",
                   "year",
                   "yvar"))
