@@ -3,7 +3,7 @@
 # Antimicrobial Resistance (AMR) Analysis                              #
 #                                                                      #
 # SOURCE                                                               #
-# https://gitlab.com/msberends/AMR                                     #
+# https://github.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
 # (c) 2018-2020 Berends MS, Luz CF et al.                              #
@@ -16,13 +16,13 @@
 # We created this package for both routine data analysis and academic  #
 # research and it was publicly released in the hope that it will be    #
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
-# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
+# Visit our website for more info: https://msberends.github.io/AMR.    #
 # ==================================================================== #
 
 context("data.R")
 
 test_that("data sets are valid", {
-  
+  skip_on_cran()
   expect_true(check_dataset_integrity()) # in misc.R
   
   # IDs should always be unique
@@ -38,10 +38,11 @@ test_that("data sets are valid", {
   expect_true(all(rsi_translation$mo %in% microorganisms$mo))
   expect_false(any(is.na(microorganisms.codes$code)))
   expect_false(any(is.na(microorganisms.codes$mo)))
-
+  expect_false(any(microorganisms.translation$mo_old %in% microorganisms$mo))
+  
   # antibiotic names must always be coercible to their original AB code
   expect_identical(antibiotics$ab, as.ab(antibiotics$name))
-
+  
   # there should be no diacritics (i.e. non ASCII) characters in the datasets (CRAN policy)
   datasets <- data(package = "AMR", envir = asNamespace("AMR"))$results[, "Item"]
   for (i in seq_len(length(datasets))) {
@@ -51,6 +52,8 @@ test_that("data sets are valid", {
 })
 
 test_that("creation of data sets is valid", {
+  skip_on_cran()
+  
   df <- create_MO_lookup()
   expect_lt(nrow(df[which(df$prevalence == 1), ]), nrow(df[which(df$prevalence == 2), ]))
   expect_lt(nrow(df[which(df$prevalence == 2), ]), nrow(df[which(df$prevalence == 3), ]))
@@ -58,19 +61,18 @@ test_that("creation of data sets is valid", {
                     "kingdom", "phylum", "class", "order", "family", "genus", "species", "subspecies",
                     "rank", "ref", "species_id", "source", "prevalence", "snomed",
                     "kingdom_index", "fullname_lower", "g_species") %in% colnames(df)))
-
+  
   olddf <- create_MO.old_lookup()
   expect_true(all(c("fullname", "fullname_new", "ref", "prevalence",
                     "fullname_lower", "g_species") %in% colnames(olddf)))
   
-  old <- make_trans_tbl()
-  expect_gt(length(old), 0)
-  
 })
 
 test_that("CoL version info works", {
- expect_identical(class(catalogue_of_life_version()),
-                  c("catalogue_of_life_version", "list"))
-
+  skip_on_cran()
+  
+  expect_identical(class(catalogue_of_life_version()),
+                   c("catalogue_of_life_version", "list"))
+  
   expect_output(print(catalogue_of_life_version()))
 })
